"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable no-console */
const fs_extra_1 = require("fs-extra");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const path_1 = require("path");
const paths_1 = require("../config/paths");
const updateREADMEFile_1 = tslib_1.__importDefault(require("./fns/updateREADMEFile"));
const updateLicense_1 = tslib_1.__importDefault(require("./fns/updateLicense"));
const genDoczFiles_1 = tslib_1.__importDefault(require("./genDoczFiles"));
/**
 * 更新模块配置信息
 *
 * @param {string} projectPath
 * @param {CreateOptions} options
 */
async function updatePackageInfo(projectPath, options) {
    const packagePath = path_1.resolve(projectPath, 'package.json');
    const packageInfo = await fs_extra_1.readJSON(packagePath);
    packageInfo.version = options.packageVersion;
    packageInfo.name = options.packageName;
    packageInfo.description = options.packageDescription;
    await fs_extra_1.outputJSON(packagePath, packageInfo, {
        spaces: 2,
    });
}
/**
 * 更新项目配置
 *
 * @param {string} projectPath
 * @param {CreateOptions} options
 */
async function updateProjectConfig(projectPath, options) {
    const configPath = path_1.resolve(projectPath, 'ts-lib.config.json');
    const projectConfig = await fs_extra_1.readJSON(configPath);
    projectConfig.npmScope = options.npmScope || options.packageName;
    await fs_extra_1.outputJSON(configPath, projectConfig, {
        spaces: 2,
    });
}
/**
 * 更新tsconfig配置
 *
 * @param {string} projectPath
 * @param {CreateOptions} options
 */
async function updateTsConfig(projectPath, options) {
    const tsconfigPath = path_1.resolve(projectPath, 'tsconfig.json');
    const tsconfig = await fs_extra_1.readJSON(tsconfigPath);
    tsconfig.compilerOptions.paths = {
        [`@${options.npmScope || options.packageName}/*`]: ['packages/*/src'],
    };
    await fs_extra_1.outputJSON(tsconfigPath, tsconfig, {
        spaces: 2,
    });
}
/**
 * 生成monorepo模式的项目
 *
 * @param {CreateOptions} options
 */
async function genMonorepoProject(options) {
    const projectPath = paths_1.resolveRoot(options.projectName);
    const exists = await fs_extra_1.pathExists(projectPath);
    if (exists) {
        console.error(chalk_1.default.red(`已经存在${options.projectName}文件夹，请选择一个新的项目名称。`));
        process.exit(1);
    }
    await fs_extra_1.copy(paths_1.COMMON_TEMPLATE_PATH, projectPath);
    await fs_extra_1.copy(paths_1.MONOREPO_TEMPLATE_PATH, projectPath);
    await fs_extra_1.copy(paths_1.GIT_IGNORE_FILE_PATH, path_1.resolve(projectPath, '.gitignore'));
    await updatePackageInfo(projectPath, options);
    await updateProjectConfig(projectPath, options);
    await updateREADMEFile_1.default(projectPath, options);
    await updateLicense_1.default(projectPath, options);
    await updateTsConfig(projectPath, options);
    await fs_extra_1.remove(path_1.resolve(projectPath, 'src'));
    if (options.docz) {
        await genDoczFiles_1.default(projectPath, options);
        await fs_extra_1.remove(path_1.resolve(projectPath, 'docs/Counter.mdx'));
    }
}
exports.default = genMonorepoProject;
//# sourceMappingURL=genMonorepoProject.js.map